import { Component, OnInit, Inject, AfterViewInit, ViewChild } from '@angular/core';
import { Observable } from 'rxjs';
import { OrdersService } from './order.data.service';
import { PageService, FreezeService, SortService, GroupService, FilterService, GridComponent, IFilterUI} from '@syncfusion/ej2-angular-grids';
import { DataStateChangeEventArgs, Column } from '@syncfusion/ej2-grids';
import { NgModel } from '@angular/forms';
import { DropDownList, MultiSelect } from '@syncfusion/ej2-dropdowns';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  providers: [OrdersService, PageService, FreezeService, SortService, GroupService, FilterService]
})
export class AppComponent implements OnInit, AfterViewInit {
   
  public data: Observable<DataStateChangeEventArgs>;
  public pageOptions: Object;
  public state: DataStateChangeEventArgs;
  constructor(public service: OrdersService) {
    this.data = service;
  }

  paging = { skip: 0, take: 20 };
  templateOptions: IFilterUI;
  public columns: any;
  @ViewChild('grid') grid: GridComponent;
  @ViewChild('template1') template1: NgModel;
  @ViewChild('template2') template2: NgModel;

  dataStateChange(state: DataStateChangeEventArgs): void {
    this.service.execute(state);
  }

  ngOnInit(): void {
    this.pageOptions = { pageSize: 5, pageCount: 4 };
    this.service.execute(this.paging);
    this.columns = [
      { field: 'OrderID', headerText: 'Order ID', isPrimaryKey: true, width: 120, textAlign: 'Right', uid:"grid_column_01" },
      { field: 'Freight', width: 125, format: 'C2', uid: "grid_column_02" },
      { field: 'CustomerID', headerText: 'Customer ID', width: 130, template: '#template2', uid:"grid_column_03"},
      { field: 'ShipName', headerText: 'Ship Name', width: 180, uid: "grid_column_04" }
    ];

    this.templateOptions = {
      create: (args: { element: Element, column: Column }) => {
        const dd = document.createElement('input');
        dd.id = 'OrderID';
        return dd;
      },
      write: (args: { element: Element, column: Column }) => {
        setTimeout(() => {
          const source: string[] = ['All', 'VINET', 'HANAR', 'VICTE'];
          const msObject: MultiSelect = new MultiSelect({
            dataSource: source,
            mode:"CheckBox", // doesnt work!
            select(e: any) {
              // here you can filter the column from you custom data with selected value.  
            }
          });
          msObject.appendTo("#OrderID"); 
        }, 0);
        
      },
    };
  }

  ngAfterViewInit(): void {
    this.columns.forEach((item: any) => {
      if (item.template != null) {
        const column = this.grid.getColumnByUid(item.uid);
        if (column != null) {
          switch (item.template) {
          case "#template1":
            column.template = this.template1 as any;
            break;
          case "#template2":
              column.template = this.template2 as any;
              column.filterBarTemplate = this.templateOptions;
            break;
          default:
          }
        }
      }
    });
  }


}
